# server

HTTP server.

## Features

- High performance
- Low latency
- Radix tree routing

## Installation

```shell
go get git.akyoto.dev/go/server
```

## Usage

```go
s := server.New()

// Static route
s.Get("/", func(ctx server.Context) error {
	return ctx.String("Hello")
})

// Parameter route
s.Get("/blog/:post", func(ctx server.Context) error {
	return ctx.String(ctx.Get("post"))
})

// Wildcard route
s.Get("/images/*file", func(ctx server.Context) error {
	return ctx.String(ctx.Get("file"))
})

s.Run(":8080")
```

## Tests

```
PASS: TestRouter
PASS: TestMiddleware
PASS: TestPanic
PASS: TestRun
PASS: TestUnavailablePort
coverage: 100.0% of statements
```

## Benchmarks

```
BenchmarkStatic/#00-12          32963155                30.88 ns/op            0 B/op          0 allocs/op
BenchmarkStatic/hello-12        31640433                37.92 ns/op            0 B/op          0 allocs/op
BenchmarkStatic/hello/world-12  22497412                52.57 ns/op            0 B/op          0 allocs/op
BenchmarkGitHub/gists/:id-12    24162244                49.70 ns/op            0 B/op          0 allocs/op
BenchmarkGitHub/repos/:a/:b-12  18865028                59.22 ns/op            0 B/op          0 allocs/op
```

## License

Please see the [license documentation](https://akyoto.dev/license).

## Copyright

© 2023 Eduard Urbach
